@@ -52,13 +52,13 @@ package com.openexchange.admin.autocontextid.storage.mysqlStorage;
 import java.sql.Connection;
 import java.sql.SQLException;
 import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 import com.openexchange.admin.autocontextid.daemons.ClientAdminThreadExtended;
 import com.openexchange.admin.autocontextid.storage.sqlStorage.OXAutoCIDSQLStorage;
 import com.openexchange.admin.rmi.exceptions.PoolException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.groupware.impl.IDGenerator;
+import com.openexchange.log.LogFactory;
 
 /**
  * @author choeger
@@ -77,9 +77,6 @@ public final class OXAutoCIDMySQLStorage extends OXAutoCIDSQLStorage {
         super();
     }
 
-    /* (non-Javadoc)
-     * @see com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface#generateContextId()
-     */
     @Override
     public int generateContextId() throws StorageException {
         final Connection con;
@@ -89,25 +86,31 @@ public final class OXAutoCIDMySQLStorage extends OXAutoCIDSQLStorage {
             log.error(e.getMessage(), e);
             throw new StorageException(e.getMessage());
         }
+        boolean rollback = false;
         try {
             con.setAutoCommit(false);
+            rollback = true;
             int id = IDGenerator.getId(con, -2);
             con.commit();
+            rollback = false;
             return id;
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
-            doRollback(con);
             throw new StorageException(e.getMessage());
         } finally {
+            if (rollback) {
+                doRollback(con);
+            }
             cache.closeConfigDBSqlStuff(con, null);
         }
     }
 
     private static void doRollback(final Connection con) {
-        try {
-            con.rollback();
-        } catch (final SQLException e2) {
-            log.error("Error doing rollback", e2);
+        if (null != con) {
+            try {
+                con.rollback();
+            } catch (final SQLException e2) {
+                log.error("Error doing rollback", e2);
+            }
         }
     }
 
